/*
 * Copyright (c) 2013-2015 BlackBerry Limited.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import bb.cascades 1.3
import "Sheets"

Page {
    titleBar: TitleBar {
        title: qsTr("Last 30 apps used") + Retranslate.onLanguageChanged
    }

    onCreationCompleted: {
        Application.fullscreen.connect(onFullscreen)
    }
    
    function onFullscreen() {
        console.log("onFullscreen()")
        _app.sendToHL("SAVE")
    }
    
    attachedObjects: [
        RenderFence {
            raised: true
            onReached: { _app.sendToHL("UI_START") }
        },
        Stats { id: statsSheet }
    ]
    
    Menu.definition: MenuDefinition {
        id: menuDefinition
        actions: [
            ActionItem {
                title: qsTr("Shutdown") + Retranslate.onLanguageChanged
                onTriggered: { _app.shutdown() }
            },
            ActionItem {
                title: qsTr("To Hub") + Retranslate.onLanguageChanged
                onTriggered: { 
                    _app.sendToHL("SAVE")
                    _app.sendToHL("SEND_TO_HUB")
                }
            },
            ActionItem {
                title: qsTr("Stats") + Retranslate.onLanguageChanged
                onTriggered: { 
                    statsSheet.open()
                }
            }
        ] 
    }
    
    Container {
        ListView {
            property variant typeList: ["Android", "Homescreen", "Hub", "Native", "Screen Off"]
            dataModel: _app.dataModel
            listItemComponents: [
                ListItemComponent {
                    StandardListItem {
                        title: ListItemData.name
                        description: ListItemData.description
                        status: ListItem.view.typeList[ListItemData.type] + " - " + ListItemData.timeSpent + " seconds"
                        imageSource: ListItemData.icon
                        /*
                        description: ListItemData.appDescription
                        title: ListItemData.appName
                        status: ListItemData.packageName
                        imageSource: ListItemData.appIconPath
                        */
                    }
                }
            ]
        }
    }
}
